@@ -16,21 +16,28 @@ AUTH_TEST = getattr(settings, 'AJAXIMAGE_AUTH_TEST', lambda u: u.is_staff)
 FILENAME_NORMALIZER = getattr(settings, 'AJAXIMAGE_FILENAME_NORMALIZER', slugify)
 
 
-@csrf_exempt
 @require_POST
 @user_passes_test(AUTH_TEST)
 def ajaximage(request, upload_to=None, max_width=None, max_height=None, crop=None, form_class=FileForm):
     form = form_class(request.POST, request.FILES)
     if form.is_valid():
         file_ = form.cleaned_data['file']
-        image_types = ['image/png', 'image/jpg', 'image/jpeg', 'image/pjpeg', 'image/gif']
+
+        image_types = ['image/png', 'image/jpg', 'image/jpeg', 'image/pjpeg',
+                       'image/gif']
+
         if file_.content_type not in image_types:
-            return HttpResponse(status=403, content='Bad image format')
+            data = json.dumps({'error': 'Bad image format.'})
+            return HttpResponse(data, content_type="application/json", status=403)
+
         file_ = resize(file_, max_width, max_height, crop)
         file_name, extension = os.path.splitext(file_.name)
         safe_name = '{0}{1}'.format(FILENAME_NORMALIZER(file_name), extension)
+
         name = os.path.join(upload_to or UPLOAD_PATH, safe_name)
         path = default_storage.save(name, file_)
         url = default_storage.url(path)
+
         return HttpResponse(json.dumps({'url': url, 'filename': path}))
+
     return HttpResponse(status=403)
